% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/P_val_Bootstrap.R
\name{P.value.Bootstrap}
\alias{P.value.Bootstrap}
\title{P-value for testing of treatment efficacy for the adaptive trial design}
\usage{
P.value.Bootstrap(Trial, active.control = TRUE, test.arm,
  non.inf.delta = 0.12, arrival.rate = 4, Prior10 = c(1, 1),
  Prior11 = c(1, 1), t_SEP_OK = 14, t_EP_OK = 34, HRR = NULL,
  Delta = 0, TOX.rate = 1, TOX.threshold = 1, PTE.threshold = 0,
  a = 0.004, b = 1.3, c = 2, acc.min = 0, nr.datasets = 500)
}
\arguments{
\item{Trial}{Outcome  data for the adaptive trial Trial}

\item{active.control}{If \code{active.control = TRUE},
trial with active control,
otherwise, with \code{active.control = FALSE}, a trial with historical control with response rate \code{p_0=HRR} is used for comparison.}

\item{test.arm}{Which regemen should be tested}

\item{non.inf.delta}{The non-inferiority margin.}

\item{arrival.rate}{Expected or estimated accrual rate of the trial.}

\item{Prior10}{A vector of two positive real numbers of Beta-prior parameters of a response at the final outcome given a negative response at the surrogate outcome.}

\item{Prior11}{A vector of two positive real numbers of Beta-prior parameters of a response at the final outcome given a positive response at the surrogate outcome.}

\item{t_SEP_OK}{Average time in weeks until the surrogate endpoint will be available.}

\item{t_EP_OK}{Average time in weeks until the final endpoint will be available.}

\item{HRR}{Historical response probability for the primary endpoint.}

\item{Delta}{Inferiority Boundary.}

\item{TOX.rate}{Toxicity threshold \code{TOX.rate}, i.e. tha maximal acepable frequencey of toxcicity related events.}

\item{TOX.threshold}{Stop an agent for toxicity if the posterior probability of the observed toxiticty rate greater than the threshold \code{TOX.rate} falls above the value \code{TOX.threshold}.}

\item{PTE.threshold}{Stop an agent for futility if the posterior probability of a positive treatment effect drops below the value \code{PTE.threshold}.}

\item{a}{Scale parameter of the power function \eqn{h(n)=an^c} used to amplify the posterior in the computation of the randomization probabilities, where \code{n} is the current number of observed events.}

\item{b}{Exponent parameter of the power function \eqn{h(n)=an^c} used to amplify the posterior in the computation of the randomization probabilities, where \code{n} is the current number of observed events.}

\item{c}{Exponent parameter of the power function used to amplify the randomization to the control nr.arms.}

\item{acc.min}{Required minimum number of patients randomized to each arm.}

\item{nr.datasets}{Number of bootstrap simulation}
}
\value{
Returns a single p-value.
}
\description{
The function computes a Bootstrap p-value for the Null hypothesis,
\eqn{H_a: p_a \leq p_0-non.inf.delta},
that a given experimental agent
has a lower response-to-treatment probability  \code{p_a}
for the primary endpoint than the active/historical response rate  \code{p_0} by at least \code{non.inf.delta}.
The test is computed independently of each treatment regimen \code{a}.
Note that this is a computational intensive procedure which may take up 20 minutes to compute.
}
\examples{
## generate trial-outcome data
Data = generate.data(nr.datasets           = 1,
                     n                     = 600,
                     arrival.rate          = 1,
                     p.interim.1           = rep(0.4, 4),
                     p.interim.2.success   = rep(0.9, 4),
                     p.interim.2.failure   = rep(0.3, 4),
                     p.primary.success     = rep(0.9, 4),
                     p.primary.failure     = rep(0.3, 4),
                     p.toxicity            = rep(0.2, 4))

# simulat an adaptive trial with active control (agent 1)
Simulate_Trial= sim.trial(
 X                = Data[[1]],
 active.control   = TRUE,
 Prior11          = c(.1*0.8,.1*.2), ## prior probability
 Prior10          = c(.1*0.3,.1*.7), ## prior probability
 t_SEP_OK         = 4,               ## surrogate endpoint available after 4 week
 t_EP_OK          = 14,              ## primary endpoint available after 4 week
 HRR              = NULL,            ## No historical response rate
 Delta            = 0,               ## no non-inferiority margin
 a                = (1/250)^5,       ## 1. randomization parameter
 b                = 5,               ## 2. randomization parameter
 c                = .25,             ## 3. randomization parameter
 TOX.rate         = .2,
 TOX.threshold    = .8,
 PTE.threshold    = 0.1,
 acc.min          = 10)              ## require at least 10 patients per regiment

## get the p-value for the 1. experimental agents (2.agent in the trial)
P.value.Bootstrap(Trial=Simulate_Trial,
  active.control  = TRUE,
  test.arm=2,
  Prior11         = c(.1*0.8,.1*.2), ## prior probability
  Prior10         = c(.1*0.3,.1*.7), ## prior probability
  t_SEP_OK        = 4,               ## 1 surrogate endpoint after 14 week
  t_EP_OK         = 14,              ## 2 surrogate endpoint  after 42 week
  HRR             = NULL,
  Delta           = 0,               ## no non-inferiority margin
  a               = (1/250)^5,       ## 1. rand parameter
  b               = 5,               ## 2. rand parameter
  c               = .25,             ## 3. rand parameter
  TOX.rate        = .2,
  TOX.threshold   = .8,
  PTE.threshold   = 0.1,
  acc.min         = 10,
  nr.datasets     = 50)
}

