% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/Posterior.Superior.R
\name{Posterior.Sup}
\alias{Posterior.Sup}
\title{Posterior probability of a positive treatment effect}
\usage{
Posterior.Sup(Events, HRR = NULL, Delta = 0, active.control = TRUE,
  Prior.fin.cond.succsess = c(1, 1), Prior.fin.cond.failure = c(1, 1))
}
\arguments{
\item{Events}{Array of currently available data in the output-format generated by \code{get.data.matrix}, i.e. Events is an array \code{Events} of dimension  \code{2 * nr.agents * 4}, where:

(a) \code{Events[,,1]} is a matrix \code{2 * nr.agents} of observed outcomes and observed responders by each agent for the 1. enpoint.

(b) \code{Events[,,2]} is a matrix \code{2 * nr.agents} of observed outcomes and observed responders by each agent for the 2. enpoint among all responders at the first endpoint.

(c) \code{Events[,,3]} is a matrix \code{2 * nr.agents} of observed outcomes and observed responders by each agent for the 2. enpoint among all non-responders at the first endpoint.

(d) \code{Events[,,4]} is a matrix \code{2 * nr.agents} of observed toxicity-outcomes and observed toxicity-event.

\code{Events[,,1]} is a 2 by nr.agent matrix of surrogate results,
where the  fist row contains  the number of oberved events by agents and
the second row contains the number of observed sucesses (response).
\code{Events[,,2]} and  \code{Events[,,2]} are data matrices for final outcome given a success or failure
at the surrogate outcome.}

\item{HRR}{Historical response rate, if first agents is not an active control arm, i.e if \code{active.control=FALSE}.}

\item{Delta}{Inferiority Boundary. The default value is \code{Delta=0}.
If \code{Delta} is different from zero, the poserior \eqn{P(\theta_a \geq \theta_0-\Delta | data)} will be computed,
where \eqn{\theta_a} represents the probability of a positive second endpoint for agenet a
and \eqn{\theta_0} is either the historical respons probability HRR or the response probability of the first agents (which represents the active standard of care agent).}

\item{active.control}{If \code{active.control=TRUE}, computes PTE for all agents \code{Events[,a,]}, \eqn{a\geq 2}, compared to active control
with control data from \code{Events[,1,]}
Otherwise, computes PTE for all agents \code{Events[,a,]}, \eqn{a\geq 1}, compared to historical response rate \code{HRR}.}

\item{Prior.fin.cond.succsess}{Prior parameter for the response rate given a success}

\item{Prior.fin.cond.failure}{Prior parameter for the response rate given a failure}
}
\value{
A vector, such that the i-th components equals to the posterior probabilities of agent i having a positive treatment effect.
}
\description{
The function computes the posterior  probability of a positive treatment effect (PTE) for each experimenal agents in the trial agains an active or historical standard-of-care control arm.
}
\examples{
## generate toy data
Events.fin.cond.succsess = rbind(c(12, 10, 14, 10), c( 6,  3,  9,  5))
Events.fin.cond.failure  = rbind(c(12, 10, 14, 10), c( 3,  1,  4,  2))
Events.sur               = rbind(c(13, 10, 10, 20), c( 2,  4,  5,  8))
nr.agnets                = 4

Names     = list( c("Total","Success"),
                  paste0("agent_", 1:nr.agnets),
                 c("surrogate", "final.given.sucess", "final.given.failure"))

Events     = array(0, dim=c(2, nr.agnets, 3), dimname=Names)
Events[,,1]=Events.sur
Events[,,2]=Events.fin.cond.succsess
Events[,,3]=Events.fin.cond.failure

## show all data
Events

## treat all agents (1 to 4) as experimental agents
## and compare to historical control
Posterior.Sup(Events                  = Events,
              HRR                     = .2,
              active.control          = FALSE,
              Prior.fin.cond.succsess = c(1,1),
              Prior.fin.cond.failure  = c(1,1))


## treat first agent as standard of care
## and compare agent 2-4 to the active standard of care
Posterior.Sup(Events                  = Events,
              HRR                     = NULL,
              active.control          = TRUE,
              Prior.fin.cond.succsess = c(1,1),
              Prior.fin.cond.failure  = c(1,1))
}

