% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/Rand.pr.R
\name{Rand.pr}
\alias{Rand.pr}
\title{Generate random numbers of treatment assignment}
\usage{
Rand.pr(Pr.PTE, n.draws = 1, Observed.events, accrual, acc.min = 0, a, b, c,
  STATUS, active.control = TRUE)
}
\arguments{
\item{Pr.PTE}{A cector of posterior probabilities  of a positive treatment effect (PTE) computed with \code{Posterior.Sup}.}

\item{n.draws}{Number of random numbers, which should be generated.}

\item{Observed.events}{The total number of observed second interim events in the trial.}

\item{accrual}{The total number of treatment assignments in the trial.}

\item{acc.min}{Required minimum number of patients randomized to each arm.}

\item{a}{Scale parameter of the power function \eqn{h(n)=an^c} used to amplify the posterior in the computation of the randomization probabilities, where \code{n} is the current number of observed events.}

\item{b}{Exponent parameter of the power function \eqn{h(n)=an^c} used to amplify the posterior in the computation of the randomization probabilities, where \code{n} is the current number of observed events.}

\item{c}{Exponent parameter of the power function used to amplify the randomization to the control nr.arms.}

\item{STATUS}{Status matrix of dimension \eqn{2 \times } number of agents in the trial.
Where the \code{STATUS[1,a]==0} indicates that agent \code{a} is still active and \code{STATUS[1,a]==1,2} indicate that agent \code{a} was dropted for futility or toxicity at time \code{STATUS[2,a]}.}

\item{active.control}{If \code{active.control = TRUE}, randomiza with active control, otherwise randomiza without active control.}
}
\value{
A vector of \code{n.draws} random numbers.
}
\description{
The function computes the vector of Bayesian adaptive randomizatio probabilities \eqn{p=(p_1, \cdots, p_A)} based on the vector of posterior probabilities of a positive treatment effect.
And generates iid random treatment assignments from p such that each treatment assignment equals agents a with probability \eqn{p_a}.
}
\examples{
## generate toy data
Events.fin.cond.succsess = rbind(c(12, 10, 14, 10), c( 6,  3,  9,  5))
Events.fin.cond.failure  = rbind(c(12, 10, 14, 10), c( 3,  1,  4,  2))
Events.sur               = rbind(c(13, 10, 10, 20), c( 2,  4,  5,  8))
nr.agnets                = 4

Names     = list( c("Total","Success"),
                  paste0("agent_", 1:nr.agnets),
                 c("surrogate", "final.given.sucess", "final.given.failure"))

Events     = array(0, dim=c(2, nr.agnets, 3), dimname=Names)
Events[,,1]=Events.sur
Events[,,2]=Events.fin.cond.succsess
Events[,,3]=Events.fin.cond.failure

## show all data
Events

## treat first agent as standard of care
## and compare agent 2-4 to the active standard of care
P.PTE = Posterior.Sup(  Events,
                        HRR                     = NULL,
                        active.control          = TRUE,
                        Prior.fin.cond.succsess = c(1,1),
                        Prior.fin.cond.failure  = c(1,1))

## draw 20 random treatment assignments
Rand.pr(Pr.PTE           = P.PTE,
        n.draws          = 20,                 ## require 20 random numbers
        Observed.events  = sum(Events[1,,-1]),
        accrual          = rowSums(Events[1,,-1]),
        acc.min          = 10,
        a=1, b=0, c=0,
        active.control   = TRUE,            ## agent 1 is active control
        STATUS           = matrix(0, 2, 3)) ## all agants are active
}

