% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/Stop.R
\name{Stopping.rule}
\alias{Stopping.rule}
\title{Early stopping rule}
\usage{
Stopping.rule(STATUS, Event.Tox.mat, Pr.PTE, TOX.rate, PTE.threshold,
  TOX.threshold, active.control, Time)
}
\arguments{
\item{STATUS}{Current status of each agent in the trial.  \code{STATUS} is a matrix with \code{2} rows and one column for each agent.
If \code{STATUS[1,a]=0} then agent a is active.
Otherwise if \code{STATUS[1,a]=1} or \code{STATUS[1,a]=2} then the a-th agent was stop for futility or toxicity at time \code{STATUS[2,a]}.}

\item{Event.Tox.mat}{An array of summary statistics dimension  \code{2 * nr.agents * 4}, where \code{Event.Tox.mat}

(a) \code{Event.Tox.mat[,,1]} is a matrix \code{2 * nr.agents} of observed outcomes and observed responders by each agent for the 1. enpoint.

(b) \code{Event.Tox.mat[,,2]} is a matrix \code{2 * nr.agents} of observed outcomes and observed responders by each agent for the 2. enpoint among all responders at the first endpoint.

(c) \code{Event.Tox.mat[,,3]} is a matrix \code{2 * nr.agents} of observed outcomes and observed responders by each agent for the 2. enpoint among all non-responders at the first endpoint.

(d) \code{Event.Tox.mat[,,4]} is a matrix \code{2 * nr.agents} of observed toxicity-outcomes and observed toxicity-event.

\code{Event.Tox.mat} is either generted by hand or using the funtion \code{generate.data}.}

\item{Pr.PTE}{A vector of posterior probabilities of a positive treatment effect for each eperimental agent.
The vector is typically generated with \code{Posterior.Sup}.}

\item{TOX.rate}{Toxicity threshold \code{TOX.rate}, i.e. tha maximal acepable frequencey of toxcicity related events.}

\item{PTE.threshold}{Stop an agent for futility if the posterior probability of a positive treatment effect drops below the value \code{PTE.threshold}.}

\item{TOX.threshold}{Stop an agent for toxicity if the posterior probability of the observed toxiticty rate greater than the threshold \code{TOX.rate} falls above the value \code{TOX.threshold}.}

\item{active.control}{If \code{active.control=TRUE} the first agent (and the data in \code{Event.Tox.mat[,1,]}) are treated as an active standard-of-care agent.
Otherwise \code{active.control=FALSE} treats all agents in the trial as experimental agents and compares all agents agains a historical standard-of-care.}

\item{Time}{Current process time of the trial, i.e. time since initiation of the trial.}
}
\value{
A status matrix, \code{STATUS}, with with \code{2} rows and one column for each agent.
Where  \code{STATUS[1,a]=0} if agent a is active and
 \code{STATUS[1,a]=1} or \code{STATUS[1,a]=2} if the a-th agent was stop for futility or toxicity at time \code{STATUS[2,a]}.
}
\description{
The function provied early stopping rules for futility and toxicity.
An experimental agents is droped for futility if the posterior probability of a positive treatment
effect falls below a treshold.
Similarly an experimental agents is droped for toxicity,
if the posterior probability of toxicity frequency being greater than a given maximum toxicity level reaches a given treshold
}
\examples{
set.seed(121)
### generate one dataset of trial outcome data containing 30 patients
Data = generate.data(nr.datasets           = 1,
                     n                     = 30,
                     arrival.rate          = 1,
                     p.interim.1           = rep(0.4, 4),
                     p.interim.2.success   = rep(0.9, 4),
                     p.interim.2.failure   = rep(0.3, 4),
                     p.primary.success     = rep(0.9, 4),
                     p.primary.failure     = rep(0.3, 4),
                     p.toxicity            = rep(0.2, 4))

### randomize all 30 patients at random to a treatment agent
Data[[1]][,2] = sample(1:4, 30, TRUE)

### retrive first and second outcome by agents
Events = get.data.matrix(
Data.matrix  = Data[[1]],
nr.agents    = 4,   ## 4 agents
time.current = 25,  ## trial open for 25 weeks
time.early   = 4,   ## 4 week 1. endpoint
time.final   = 8)   ## 8 week 1. endpoint

### Posterior probability of a positive treatment effect
Pr.PTE = Posterior.Sup(Events        = Events,
             HRR                     = .2,
             active.control          = FALSE,
             Prior.fin.cond.failure  = c(1,1))

###
STATUS = matrix(0, 2, 4)

Stopping.rule(STATUS         = STATUS,
              Event.Tox.mat  = Events,
              Pr.PTE         = Pr.PTE,
              TOX.rate       = .2,
              PTE.threshold  = 0.7,
              TOX.threshold  = .1,
              active.control = FALSE,
              Time           = 20)
}

