% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/generate.data.R
\name{generate.data}
\alias{generate.data}
\title{Generate arrival and outcome data}
\usage{
generate.data(nr.datasets, n, arrival.rate, p.interim.1, p.interim.2.success,
  p.interim.2.failure, p.primary.success, p.primary.failure, p.toxicity)
}
\arguments{
\item{nr.datasets}{Number of datasets to be generated.}

\item{n}{Total number of patients for each dataset in the trial.}

\item{arrival.rate}{The expected average number of patients entering the trial within one week.}

\item{p.interim.1}{A vector of response probabilities for the first interim outcome for each agent.}

\item{p.interim.2.success}{A vector of response probabilities for the second interim outcome for each agent,
given a favourable outcome for the first interim outcome.}

\item{p.interim.2.failure}{A vector of response probabilities for the second interim outcome for each agent,
given an unfavourable outcome for the first interim outcome.}

\item{p.primary.success}{A vector of response probabilities for the primary outcome for each agent,
given a favourable outcome for the second interim outcome.}

\item{p.primary.failure}{A vector of response probabilities for the primary outcome for each agent,
given an unfavourable outcome at the second interim outcome.}

\item{p.toxicity}{Probability of a toxicity related event.}
}
\value{
The funcion returns a list of \code{nr.datasets} trial datasets.

Each dataset (element of the list) is a matrix  of \code{n} rows, wherer each row represents a patient.
For each patient the first two entries (columns) indicate the arrival time and treatment-with-agent variable.
At generation of the outcome data the treatment-with-agent information is unknown, hence the 2. column contains only \code{NA}'s.
The remaining \code{3} to \code{2 + 3*} columns contain the first and second interim endpoint, the primary endpoint
and the troxicity outcome for each treatment agent.
}
\description{
The function generates multiple datasets of patient arrival times,
two surrogate enpoints,  the primary outcome, and
the toxicity enpoint for each patient and each treatment agent.
}
\examples{
Data = generate.data(
  nr.datasets           = 1,   ## only one dataset
  n                     = 10,  ## total sample size of 10 patient
  arrival.rate          = 1,      ## average of one arriving patient per week
  p.interim.1           = rep(0.4, 4),
  p.interim.2.success   = rep(0.9, 4),
  p.interim.2.failure   = rep(0.3, 4),
  p.primary.success     = rep(0.9, 4),
  p.primary.failure     = rep(0.3, 4),
  p.toxicity            = rep(0.2, 4))
}

