% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/Data.Matrix.R
\name{get.data.matrix}
\alias{get.data.matrix}
\title{Convert currently available data into a summary array}
\usage{
get.data.matrix(Data.matrix, nr.agents, time.current, time.early, time.final)
}
\arguments{
\item{Data.matrix}{Data.matrix}

\item{nr.agents}{The number of experimental plus control agents in the trial.}

\item{time.current}{Current process time of the trial.}

\item{time.early}{The time between from beginning of treatment and availablility of the first available endpoint.}

\item{time.final}{The time between from beginning of treatment and availablility of the second available endpoint.}
}
\value{
The function returns an array \code{Events} of dimension  \code{2 * nr.agents * 4}, where:

(a) \code{Events[,,1]} is a matrix \code{2 * nr.agents} of observed outcomes and observed responders by each agent for the 1. enpoint.

(b) \code{Events[,,2]} is a matrix \code{2 * nr.agents} of observed outcomes and observed responders by each agent for the 2. enpoint among all responders at the first endpoint.

(c) \code{Events[,,3]} is a matrix \code{2 * nr.agents} of observed outcomes and observed responders by each agent for the 2. enpoint among all non-responders at the first endpoint.

(d) \code{Events[,,4]} is a matrix \code{2 * nr.agents} of observed toxicity-outcomes and observed toxicity-event.
}
\description{
The function converts currently available data into an array of sufficient statistics.
}
\examples{
set.seed(121)
### generate one dataset of trial outcome data containing 30 patients
Data = generate.data(nr.datasets           = 1,
                     n                     = 30,
                     arrival.rate          = 1,
                     p.interim.1           = rep(0.4, 4),
                     p.interim.2.success   = rep(0.9, 4),
                     p.interim.2.failure   = rep(0.3, 4),
                     p.primary.success     = rep(0.9, 4),
                     p.primary.failure     = rep(0.3, 4),
                     p.toxicity            = rep(0.2, 4))

### randomize all 30 patients at random to a treatment agent
Data[[1]][,2] = sample(1:4, 30, TRUE)

### retrive first and second outcome by agents
get.data.matrix(
Data.matrix  = Data[[1]],
nr.agents    = 4,   ## 4 agents
time.current = 25,  ## trial open for 25 weeks
time.early   = 4,   ## 4 week 1. endpoint
time.final   = 8)   ## 8 week 1. endpoint
}

