% Generated by roxygen2 (4.1.0): do not edit by hand
% Please edit documentation in R/sim.trial2.R
\name{sim.trial}
\alias{sim.trial}
\title{Simulate Response Adaptive Trial}
\usage{
sim.trial(X, active.control = FALSE, Prior10 = c(1, 1), Prior11 = c(1, 1),
  t_SEP_OK = 14, t_EP_OK = 34, HRR = NULL, Delta = 0, TOX.rate = 1,
  TOX.threshold = 1, PTE.threshold = 0, a = 0.004, b = 1.3, c = 2,
  acc.min = 0)
}
\arguments{
\item{X}{Outcome data generated with \code{generate.data}.}

\item{active.control}{If \code{active.control = TRUE}, trial with active control, otherwsie trial with historical control of response rate \code{HRR}.}

\item{Prior10}{A vector of two positive real numbers of Beta-prior parameters of a response at the final outcome given a negative response at the surrogate outcome.}

\item{Prior11}{A vector of two positive real numbers of Beta-prior parameters of a response at the final outcome given a positive response at the surrogate outcome.}

\item{t_SEP_OK}{Average time in weeks until the surrogate endpoint will be available.}

\item{t_EP_OK}{Average time in weeks until the final endpoint will be available.}

\item{HRR}{Historical response probability for the primary endpoint.}

\item{Delta}{Inferiority Boundary.}

\item{TOX.rate}{Toxicity threshold \code{TOX.rate}, i.e. tha maximal acepable frequencey of toxcicity related events.}

\item{TOX.threshold}{Stop an agent for toxicity if the posterior probability of the observed toxiticty rate greater than the threshold \code{TOX.rate} falls above the value \code{TOX.threshold}.}

\item{PTE.threshold}{Stop an agent for futility if the posterior probability of a positive treatment effect drops below the value \code{PTE.threshold}.}

\item{a}{Scale parameter of the power function \eqn{h(n)=an^c} used to amplify the posterior in the computation of the randomization probabilities, where \code{n} is the current number of observed events.}

\item{b}{Exponent parameter of the power function \eqn{h(n)=an^c} used to amplify the posterior in the computation of the randomization probabilities, where \code{n} is the current number of observed events.}

\item{c}{Exponent parameter of the power function used to amplify the randomization to the control nr.arms.}

\item{acc.min}{Required minimum number of patients randomized to each arm.}
}
\value{
Returns a matrix of trial data.
}
\description{
The function simulates one response adaptive trial with early enpoints and a Bayesian adaptive randomization model.
}
\examples{
### generate outcome data under treatment with each agents.
Data = generate.data(
   nr.datasets           = 2,    ## simulate 2 datasets
   n                     = 100,  ## each with 100 patients
   arrival.rate          = 1,    ## mean accrual of 1 patients per week
   p.interim.1           = rep(0.4, 4),
   p.interim.2.success   = rep(0.9, 4),
   p.interim.2.failure   = rep(0.3, 4),
   p.primary.success     = rep(0.9, 4),
   p.primary.failure     = rep(0.3, 4),
   p.toxicity            = rep(0.2, 4))

### simulate a trial
sim.trial(
 X                = Data[[1]],
 active.control   = TRUE,
 Prior11          = c(.1*0.8,.1*.2), ## prior probability
 Prior10          = c(.1*0.3,.1*.7), ## prior probability
 t_SEP_OK         = 4,               ## surrogate endpoint available after 4 week
 t_EP_OK          = 14,              ## primary endpoint available after 4 week
 HRR              = 0.6,             ## historical response rate
 Delta            = 0.12,            ## 12\% non-inferiority margin
 a                = (1/250)^5,       ## first randomization parameter
 b                = 5,               ## second randomization parameter
 c                = .25,             ## third randomization parameter
 acc.min          = 10)              ## require at least 10 patients per regiment
}

